import { useEffect, useState } from 'react';
import { toast } from 'sonner';
import { useNavigate, Link } from 'react-router-dom';
import { ArrowLeft, CreditCard, HandCoins, Truck } from 'lucide-react';

import { useCartStore } from '@/lib/store';
import { useOrderStore } from '@/lib/orderStore';
import { useAuthStore } from '@/lib/authStore';

import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Label } from '@/components/ui/label';
import { Textarea } from '@/components/ui/textarea';
import { RadioGroup, RadioGroupItem } from '@/components/ui/radio-group';

export default function Checkout() {
  const navigate = useNavigate();
  const { cart, clearCart, initializeCart } = useCartStore();
  const { addOrder } = useOrderStore();
  const { user, isAuthenticated } = useAuthStore();

  const [formData, setFormData] = useState({
    name: '',
    email: '',
    phone: '',
    address: '',
    city: '',
    zipCode: '',
    paymentMethod: 'credit-card',
    specialInstructions: '',
  });

  const [errors, setErrors] = useState({});
  const [isSubmitting, setIsSubmitting] = useState(false);

  useEffect(() => {
    initializeCart();

    // Redirect to login if not authenticated
    if (!isAuthenticated) {
      toast.error('Authentication required!', {
        description: 'Please sign in to checkout.',
      });
      navigate('/login');
      return;
    }

    // Pre-fill user data if available
    if (user) {
      setFormData((prev) => ({
        ...prev,
        name: user.name || '',
        email: user.email || '',
      }));
    }
  }, [initializeCart, isAuthenticated, user, navigate]);

  useEffect(() => {
    if (isAuthenticated && cart.length === 0) {
      toast.error('Cart is empty!', {
        description: 'Please add items to your cart before checking out.',
      });
      navigate('/menu');
    }
  }, [cart.length, isAuthenticated, navigate]);

  // If not authenticated, don't render the checkout content
  if (!isAuthenticated) {
    return null;
  }

  const subtotal = cart.reduce(
    (total, item) => total + item.price * item.quantity,
    0
  );
  const tax = subtotal * 0.12; // 12% tax
  const deliveryFee = 5.99;
  const total = subtotal + tax + deliveryFee;

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData((prev) => ({
      ...prev,
      [name]: value,
    }));

    // Clear error when field is being edited
    if (errors[name]) {
      setErrors((prev) => ({
        ...prev,
        [name]: '',
      }));
    }
  };

  const validateForm = () => {
    const newErrors = {};

    if (!formData.name.trim()) newErrors.name = 'Name is required';
    if (!formData.email.trim()) {
      newErrors.email = 'Email is required';
    } else if (!/\S+@\S+\.\S+/.test(formData.email)) {
      newErrors.email = 'Email is invalid';
    }
    if (!formData.phone.trim()) newErrors.phone = 'Phone number is required';
    if (!formData.address.trim()) newErrors.address = 'Address is required';
    if (!formData.city.trim()) newErrors.city = 'City is required';
    if (!formData.zipCode.trim()) newErrors.zipCode = 'ZIP code is required';

    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = (e) => {
    e.preventDefault();

    if (!validateForm()) return;

    setIsSubmitting(true);

    // Simulate processing
    setTimeout(() => {
      const orderId = `ORD-${Date.now()}`;
      const orderDate = new Date().toISOString();

      const order = {
        id: orderId,
        date: orderDate,
        items: [...cart],
        customer: {
          name: formData.name,
          email: formData.email,
          phone: formData.phone,
          address: formData.address,
          city: formData.city,
          zipCode: formData.zipCode,
        },
        paymentMethod: formData.paymentMethod,
        specialInstructions: formData.specialInstructions,
        status: 'processing',
        subtotal,
        tax,
        deliveryFee,
        total,
      };

      addOrder(order);

      setIsSubmitting(false);
      navigate(`/confirmation?orderId=${orderId}`);

      setTimeout(() => {
        clearCart();
      }, 500);
    }, 1500);
  };

  return (
    <div className='container mx-auto px-4 py-8 md:py-12'>
      <div className='text-center mb-8'>
        <h1 className='text-4xl font-bold text-gray-800 mb-4'>Checkout</h1>
        <p className='text-gray-600'>Complete your order details below</p>
      </div>

      <div className='grid grid-cols-1 lg:grid-cols-3 gap-8'>
        <div className='lg:col-span-2'>
          <form
            onSubmit={handleSubmit}
            className='bg-white rounded-xl shadow-sm border overflow-hidden'
          >
            <div className='p-6'>
              <h2 className='text-xl font-semibold text-gray-800 mb-6'>
                Delivery Information
              </h2>

              <div className='grid grid-cols-1 md:grid-cols-2 gap-6 mb-6'>
                <div className='space-y-2'>
                  <Label htmlFor='name'>Full Name</Label>
                  <Input
                    id='name'
                    name='name'
                    value={formData.name}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.name ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.name && (
                    <p className='text-red-500 text-sm'>{errors.name}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='email'>Email Address</Label>
                  <Input
                    id='email'
                    name='email'
                    type='email'
                    value={formData.email}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.email ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.email && (
                    <p className='text-red-500 text-sm'>{errors.email}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='phone'>Phone Number</Label>
                  <Input
                    id='phone'
                    name='phone'
                    value={formData.phone}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.phone ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.phone && (
                    <p className='text-red-500 text-sm'>{errors.phone}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='address'>Delivery Address</Label>
                  <Input
                    id='address'
                    name='address'
                    value={formData.address}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.address ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.address && (
                    <p className='text-red-500 text-sm'>{errors.address}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='city'>City</Label>
                  <Input
                    id='city'
                    name='city'
                    value={formData.city}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.city ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.city && (
                    <p className='text-red-500 text-sm'>{errors.city}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='zipCode'>ZIP Code</Label>
                  <Input
                    id='zipCode'
                    name='zipCode'
                    value={formData.zipCode}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.zipCode ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.zipCode && (
                    <p className='text-red-500 text-sm'>{errors.zipCode}</p>
                  )}
                </div>
              </div>

              <div className='space-y-4 mb-6'>
                <h2 className='text-xl font-semibold text-gray-800 mb-2'>
                  Payment Method
                </h2>
                <RadioGroup
                  value={formData.paymentMethod}
                  onValueChange={(value) =>
                    setFormData((prev) => ({ ...prev, paymentMethod: value }))
                  }
                  className='flex flex-col space-y-2'
                >
                  <div className='flex items-center space-x-2'>
                    <RadioGroupItem value='credit-card' id='credit-card' />
                    <Label htmlFor='credit-card' className='flex items-center'>
                      <CreditCard className='mr-2 h-4 w-4' /> Credit Card (Pay
                      at Delivery)
                    </Label>
                  </div>
                  <div className='flex items-center space-x-2'>
                    <RadioGroupItem value='cash' id='cash' />
                    <Label htmlFor='cash' className='flex items-center'>
                      <HandCoins className='mr-2 h-4 w-4' /> Cash on Delivery
                    </Label>
                  </div>
                </RadioGroup>
              </div>

              <div className='space-y-2 mb-6'>
                <Label htmlFor='specialInstructions'>
                  Special Instructions (Optional)
                </Label>
                <Textarea
                  id='specialInstructions'
                  name='specialInstructions'
                  value={formData.specialInstructions}
                  onChange={handleChange}
                  placeholder='Any special requests for your order or delivery'
                  className='rounded-lg border-gray-200 min-h-[100px]'
                />
              </div>

              <div className='flex flex-col sm:flex-row gap-4'>
                <Button
                  type='button'
                  variant='outline'
                  asChild
                  className='border-pink-300 text-pink-600 hover:bg-pink-50 rounded-full'
                >
                  <Link to='/cart'>
                    <ArrowLeft className='mr-2 h-4 w-4' /> Back to Cart
                  </Link>
                </Button>
                <Button
                  type='submit'
                  disabled={isSubmitting}
                  className='bg-pink-500 hover:bg-pink-600 text-white rounded-full'
                >
                  {isSubmitting ? 'Processing...' : 'Complete Order'}
                </Button>
              </div>
            </div>
          </form>
        </div>

        <div className='lg:col-span-1'>
          <div className='bg-white rounded-xl shadow-sm border overflow-hidden'>
            <div className='p-6'>
              <h2 className='text-lg font-semibold text-gray-900 mb-4'>
                Order Summary
              </h2>
              <div className='flow-root'>
                <ul className='divide-y divide-gray-200'>
                  {cart.map((item) => (
                    <li key={item.id} className='py-3 flex justify-between'>
                      <div>
                        <p className='text-sm font-medium text-gray-900'>
                          {item.name}
                        </p>
                        <p className='text-sm text-gray-500'>
                          Qty: {item.quantity}
                        </p>
                      </div>
                      <p className='text-sm font-medium text-gray-900'>
                        ${(item.price * item.quantity).toFixed(2)}
                      </p>
                    </li>
                  ))}
                </ul>
              </div>
              <div className='border-t border-gray-200 mt-4 pt-4'>
                <div className='flex justify-between py-2'>
                  <dt className='text-sm text-gray-600'>Subtotal</dt>
                  <dd className='text-sm font-medium text-gray-900'>
                    ${subtotal.toFixed(2)}
                  </dd>
                </div>
                <div className='flex justify-between py-2'>
                  <dt className='text-sm text-gray-600'>Tax (12%)</dt>
                  <dd className='text-sm font-medium text-gray-900'>
                    ${tax.toFixed(2)}
                  </dd>
                </div>
                <div className='flex justify-between py-2'>
                  <dt className='text-sm text-gray-600'>Delivery Fee</dt>
                  <dd className='text-sm font-medium text-gray-900'>
                    ${deliveryFee.toFixed(2)}
                  </dd>
                </div>
                <div className='flex justify-between py-2 border-t border-gray-200'>
                  <dt className='text-base font-medium text-gray-900'>Total</dt>
                  <dd className='text-base font-medium text-pink-600'>
                    ${total.toFixed(2)}
                  </dd>
                </div>
              </div>
              <div className='mt-6 bg-blue-50 p-4 rounded-lg flex items-start'>
                <Truck className='h-5 w-5 text-blue-800 mr-2 mt-0.5' />
                <div>
                  <p className='text-sm font-medium text-blue-800'>
                    Delivery Information
                  </p>
                  <p className='text-sm text-blue-600'>
                    Your order will be delivered within 2-3 business days.
                  </p>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
}
