import { useEffect, useState } from 'react';
import { CheckCircle, Home, ShoppingBag } from 'lucide-react';
import confetti from 'canvas-confetti';
import { useNavigate, useSearchParams, Link } from 'react-router-dom';

import { useOrderStore } from '@/lib/orderStore';

import { Button } from '@/components/ui/button';

export default function Confirmation() {
  const navigate = useNavigate();
  const [searchParams, _] = useSearchParams();
  const { orders } = useOrderStore();
  const [order, setOrder] = useState(null);

  useEffect(() => {
    const orderId = searchParams.get('orderId');
    if (!orderId) {
      navigate('/');
      return;
    }

    const foundOrder = orders.find((o) => o.id === orderId);
    if (foundOrder) {
      setOrder(foundOrder);

      // Trigger confetti animation
      confetti({
        particleCount: 100,
        spread: 70,
        origin: { y: 0.6 },
      });
    } else {
      navigate('/');
    }
  }, [orders, navigate, searchParams]);

  if (!order) {
    return (
      <div className='container mx-auto px-4 py-16 text-center'>
        <p>Loading order details...</p>
      </div>
    );
  }

  return (
    <div className='container mx-auto px-4 py-8 md:py-12'>
      <div className='max-w-3xl mx-auto bg-white rounded-xl shadow-sm border overflow-hidden'>
        <div className='p-8'>
          <div className='text-center mb-8'>
            <div className='mx-auto w-16 h-16 bg-green-100 rounded-full flex items-center justify-center mb-4'>
              <CheckCircle className='h-10 w-10 text-green-500' />
            </div>
            <h1 className='text-3xl font-bold text-gray-800 mb-2'>
              Order Confirmed!
            </h1>
            <p className='text-gray-600'>
              Thank you for your order. We've received your order and will begin
              processing it right away.
            </p>
          </div>

          <div className='border-t border-b border-gray-200 py-6 mb-6'>
            <div className='flex justify-between mb-2'>
              <h2 className='text-lg font-semibold text-gray-800'>
                Order Details
              </h2>
              <p className='text-pink-600 font-medium'>
                Order #{order.id.split('-')[1]}
              </p>
            </div>
            <p className='text-gray-600 text-sm mb-4'>
              Placed on {new Date(order.date).toLocaleDateString()} at{' '}
              {new Date(order.date).toLocaleTimeString()}
            </p>

            <div className='space-y-4'>
              <div>
                <h3 className='text-sm font-medium text-gray-800 mb-2'>
                  Items Ordered:
                </h3>
                <ul className='divide-y divide-gray-200'>
                  {order.items.map((item) => (
                    <li key={item.id} className='py-3 flex justify-between'>
                      <div>
                        <p className='text-sm font-medium text-gray-900'>
                          {item.name}
                        </p>
                        <p className='text-sm text-gray-500'>
                          Qty: {item.quantity}
                        </p>
                      </div>
                      <p className='text-sm font-medium text-gray-900'>
                        ${(item.price * item.quantity).toFixed(2)}
                      </p>
                    </li>
                  ))}
                </ul>
              </div>

              <div className='pt-4'>
                <div className='flex justify-between py-1'>
                  <dt className='text-sm text-gray-600'>Subtotal</dt>
                  <dd className='text-sm font-medium text-gray-900'>
                    ${order.subtotal.toFixed(2)}
                  </dd>
                </div>
                <div className='flex justify-between py-1'>
                  <dt className='text-sm text-gray-600'>Tax</dt>
                  <dd className='text-sm font-medium text-gray-900'>
                    ${order.tax.toFixed(2)}
                  </dd>
                </div>
                <div className='flex justify-between py-1'>
                  <dt className='text-sm text-gray-600'>Delivery Fee</dt>
                  <dd className='text-sm font-medium text-gray-900'>
                    ${order.deliveryFee.toFixed(2)}
                  </dd>
                </div>
                <div className='flex justify-between py-1 border-t border-gray-200 mt-2 pt-2'>
                  <dt className='text-base font-medium text-gray-900'>Total</dt>
                  <dd className='text-base font-medium text-pink-600'>
                    ${order.total.toFixed(2)}
                  </dd>
                </div>
              </div>
            </div>
          </div>

          <div className='grid grid-cols-1 md:grid-cols-2 gap-6 mb-8'>
            <div>
              <h3 className='text-sm font-medium text-gray-800 mb-2'>
                Delivery Information:
              </h3>
              <p className='text-sm text-gray-600'>{order.customer.name}</p>
              <p className='text-sm text-gray-600'>{order.customer.address}</p>
              <p className='text-sm text-gray-600'>
                {order.customer.city}, {order.customer.zipCode}
              </p>
              <p className='text-sm text-gray-600'>{order.customer.phone}</p>
              <p className='text-sm text-gray-600'>{order.customer.email}</p>
            </div>

            <div>
              <h3 className='text-sm font-medium text-gray-800 mb-2'>
                Payment Method:
              </h3>
              <p className='text-sm text-gray-600 capitalize'>
                {order.paymentMethod === 'credit-card'
                  ? 'Credit Card (Pay at Delivery)'
                  : 'Cash on Delivery'}
              </p>

              <h3 className='text-sm font-medium text-gray-800 mt-4 mb-2'>
                Delivery Status:
              </h3>
              <div className='inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-yellow-100 text-yellow-800'>
                Processing
              </div>
            </div>
          </div>

          <div className='bg-blue-50 p-4 rounded-lg mb-8'>
            <p className='text-sm text-blue-800'>
              You will receive an email confirmation shortly at{' '}
              {order.customer.email} with your order details.
            </p>
          </div>

          <div className='flex flex-col sm:flex-row gap-4 justify-center'>
            <Button
              asChild
              className='bg-pink-500 hover:bg-pink-600 text-white rounded-full'
            >
              <Link to='/orders'>
                <ShoppingBag className='mr-2 h-4 w-4' /> View My Orders
              </Link>
            </Button>
            <Button
              variant='outline'
              asChild
              className='border-pink-300 text-pink-600 hover:bg-pink-50 rounded-full'
            >
              <Link to='/'>
                <Home className='mr-2 h-4 w-4' /> Return to Home
              </Link>
            </Button>
          </div>
        </div>
      </div>
    </div>
  );
}
