import { useState } from 'react';
import { toast } from 'sonner';
import { Clock, Mail, MapPin, Phone, Send } from 'lucide-react';

import { Map, Marker } from 'pigeon-maps';

import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Label } from '@/components/ui/label';
import { Textarea } from '@/components/ui/textarea';
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from '@/components/ui/select';
import {
  Accordion,
  AccordionContent,
  AccordionItem,
  AccordionTrigger,
} from '@/components/ui/accordion';

export default function Contact() {
  const [formData, setFormData] = useState({
    name: '',
    email: '',
    phone: '',
    subject: '',
    message: '',
  });

  const [errors, setErrors] = useState({});
  const [isSubmitting, setIsSubmitting] = useState(false);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData((prev) => ({
      ...prev,
      [name]: value,
    }));

    // Clear error when field is being edited
    if (errors[name]) {
      setErrors((prev) => ({
        ...prev,
        [name]: '',
      }));
    }
  };

  const handleSelectChange = (value) => {
    setFormData((prev) => ({
      ...prev,
      subject: value,
    }));

    if (errors.subject) {
      setErrors((prev) => ({
        ...prev,
        subject: '',
      }));
    }
  };

  const validateForm = () => {
    const newErrors = {};

    if (!formData.name.trim()) newErrors.name = 'Name is required';
    if (!formData.email.trim()) {
      newErrors.email = 'Email is required';
    } else if (!/\S+@\S+\.\S+/.test(formData.email)) {
      newErrors.email = 'Email is invalid';
    }
    if (!formData.subject) newErrors.subject = 'Subject is required';
    if (!formData.message.trim()) newErrors.message = 'Message is required';

    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = (e) => {
    e.preventDefault();

    if (!validateForm()) return;

    setIsSubmitting(true);

    setTimeout(() => {
      setIsSubmitting(false);

      toast.success('Message Sent!', {
        description: "Thank you for contacting us. We'll get back to you soon.",
      });

      setFormData({
        name: '',
        email: '',
        phone: '',
        subject: '',
        message: '',
      });
    }, 1500);
  };

  return (
    <div className='container mx-auto px-4 py-8 md:py-12'>
      <div className='text-center mb-12'>
        <h1 className='text-4xl font-bold text-gray-800 mb-4'>Contact Us</h1>
        <p className='text-gray-600 max-w-2xl mx-auto'>
          Have questions or special requests? We're here to help! Get in touch
          with our team.
        </p>
      </div>

      <div className='grid grid-cols-1 lg:grid-cols-2 gap-12'>
        <div>
          <div className='bg-white rounded-xl border shadow-sm overflow-hidden mb-8'>
            <div className='p-6'>
              <h2 className='text-2xl font-bold text-gray-800 mb-6'>
                Send Us a Message
              </h2>

              <form onSubmit={handleSubmit} className='space-y-6'>
                <div className='space-y-2'>
                  <Label htmlFor='name'>Full Name</Label>
                  <Input
                    id='name'
                    name='name'
                    placeholder='Peter Parker'
                    value={formData.name}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.name ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.name && (
                    <p className='text-red-500 text-sm'>{errors.name}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='email'>Email Address</Label>
                  <Input
                    id='email'
                    name='email'
                    type='email'
                    placeholder='yourname@email.com'
                    value={formData.email}
                    onChange={handleChange}
                    className={`rounded-lg ${
                      errors.email ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.email && (
                    <p className='text-red-500 text-sm'>{errors.email}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='phone'>Phone Number (Optional)</Label>
                  <Input
                    id='phone'
                    name='phone'
                    placeholder='(+44) 8765432109'
                    value={formData.phone}
                    onChange={handleChange}
                    className='rounded-lg border-gray-200'
                  />
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='subject'>Subject</Label>
                  <Select
                    value={formData.subject}
                    onValueChange={handleSelectChange}
                  >
                    <SelectTrigger
                      className={`rounded-lg ${
                        errors.subject ? 'border-red-500' : 'border-gray-200'
                      }`}
                    >
                      <SelectValue placeholder='Select a subject' />
                    </SelectTrigger>
                    <SelectContent>
                      <SelectItem value='general'>General Inquiry</SelectItem>
                      <SelectItem value='order'>Order Question</SelectItem>
                      <SelectItem value='custom'>
                        Custom Cake Request
                      </SelectItem>
                      <SelectItem value='feedback'>Feedback</SelectItem>
                      <SelectItem value='other'>Other</SelectItem>
                    </SelectContent>
                  </Select>
                  {errors.subject && (
                    <p className='text-red-500 text-sm'>{errors.subject}</p>
                  )}
                </div>

                <div className='space-y-2'>
                  <Label htmlFor='message'>Your Message</Label>
                  <Textarea
                    id='message'
                    name='message'
                    placeholder='Your message here...'
                    value={formData.message}
                    onChange={handleChange}
                    className={`rounded-lg min-h-[150px] ${
                      errors.message ? 'border-red-500' : 'border-gray-200'
                    }`}
                  />
                  {errors.message && (
                    <p className='text-red-500 text-sm'>{errors.message}</p>
                  )}
                </div>

                <Button
                  type='submit'
                  disabled={isSubmitting}
                  className='w-full bg-pink-500 hover:bg-pink-600 text-white rounded-full py-6'
                >
                  {isSubmitting ? (
                    'Sending...'
                  ) : (
                    <>
                      <Send className='mr-2 h-4 w-4' /> Send Message
                    </>
                  )}
                </Button>
              </form>
            </div>
          </div>
        </div>

        <div>
          <div className='bg-white rounded-xl shadow-sm border overflow-hidden mb-8'>
            <div className='p-6'>
              <h2 className='text-2xl font-bold text-gray-800 mb-6'>
                Contact Information
              </h2>

              <div className='space-y-6'>
                <div className='flex items-start'>
                  <div className='mr-4'>
                    <div className='w-10 h-10 bg-pink-100 rounded-full flex items-center justify-center'>
                      <MapPin className='h-5 w-5 text-pink-600' />
                    </div>
                  </div>
                  <div>
                    <h3 className='font-semibold text-gray-800 mb-1'>
                      Our Location
                    </h3>
                    <p className='text-gray-600'>
                      Golden Crust Bakery, Bakery Street, London, UK
                    </p>
                  </div>
                </div>

                <div className='flex items-start'>
                  <div className='mr-4'>
                    <div className='w-10 h-10 bg-blue-100 rounded-full flex items-center justify-center'>
                      <Phone className='h-5 w-5 text-blue-600' />
                    </div>
                  </div>
                  <div>
                    <h3 className='font-semibold text-gray-800 mb-1'>
                      Phone Number
                    </h3>
                    <p className='text-gray-600'>(+44) 8765432109</p>
                  </div>
                </div>

                <div className='flex items-start'>
                  <div className='mr-4'>
                    <div className='w-10 h-10 bg-yellow-100 rounded-full flex items-center justify-center'>
                      <Mail className='h-5 w-5 text-yellow-600' />
                    </div>
                  </div>
                  <div>
                    <h3 className='font-semibold text-gray-800 mb-1'>
                      Email Address
                    </h3>
                    <p className='text-gray-600'>info@goldencrust.com</p>
                  </div>
                </div>

                <div className='flex items-start'>
                  <div className='mr-4'>
                    <div className='w-10 h-10 bg-green-100 rounded-full flex items-center justify-center'>
                      <Clock className='h-5 w-5 text-green-600' />
                    </div>
                  </div>
                  <div>
                    <h3 className='font-semibold text-gray-800 mb-1'>
                      Business Hours
                    </h3>
                    <p className='text-gray-600'>
                      Everyday - 11:00 AM - 7:00 PM
                    </p>
                  </div>
                </div>
              </div>
            </div>
          </div>

          <div className='bg-white rounded-xl shadow-sm border overflow-hidden'>
            <div className='p-6'>
              <h2 className='text-2xl font-bold text-gray-800 mb-6'>
                Frequently Asked Questions
              </h2>

              <div className='space-y-4'>
                <Accordion type='single' collapsible>
                  <AccordionItem value='item-1'>
                    <AccordionTrigger>
                      How far in advance should I order a cake?
                    </AccordionTrigger>
                    <AccordionContent>
                      We recommend placing your order at least 3-5 days in
                      advance for standard cakes, and 2-3 weeks for custom or
                      wedding cakes.
                    </AccordionContent>
                  </AccordionItem>

                  <AccordionItem value='item-2'>
                    <AccordionTrigger>Do you offer delivery?</AccordionTrigger>
                    <AccordionContent>
                      Yes, we offer delivery within a 15-mile radius of our
                      bakery for a small fee. For larger orders or wedding
                      cakes, delivery is available at special rates.
                    </AccordionContent>
                  </AccordionItem>

                  <AccordionItem value='item-3'>
                    <AccordionTrigger>
                      Can you accommodate dietary restrictions?
                    </AccordionTrigger>
                    <AccordionContent>
                      We offer gluten-free and vegan options for many of our
                      cakes. Please contact us directly to discuss your specific
                      dietary needs.
                    </AccordionContent>
                  </AccordionItem>

                  <AccordionItem value='item-4'>
                    <AccordionTrigger>
                      How do I place a custom cake order?
                    </AccordionTrigger>
                    <AccordionContent>
                      You can contact us through this form, call us, or visit
                      our bakery in person to discuss your custom cake
                      requirements.
                    </AccordionContent>
                  </AccordionItem>
                </Accordion>
              </div>
            </div>
          </div>
        </div>
      </div>

      {/* Map Section */}
      <div className='mt-12 bg-white rounded-xl shadow-md overflow-hidden'>
        <div className='p-6'>
          <h2 className='text-2xl font-bold text-gray-800 mb-6 text-center'>
            Find Us
          </h2>
          <div className='relative h-[400px] bg-gray-200 rounded-lg'>
            <div className='absolute inset-0 flex items-center justify-center rounded-lg overflow-hidden'>
              <Map defaultCenter={[51.5072, 0.1276]} defaultZoom={16}>
                <Marker width={50} anchor={[51.5072, 0.1276]} />
              </Map>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
}
