import { useEffect, useState } from 'react';
import { toast } from 'sonner';
import { Search, ShoppingCart } from 'lucide-react';

import { useCartStore } from '@/lib/store';
import { useAuthStore } from '@/lib/authStore';
import { cakeData } from '@/lib/data';

import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Link, useSearchParams } from 'react-router-dom';

export default function Menu() {
  const { isAuthenticated } = useAuthStore();

  const { addToCart, initializeCart } = useCartStore();
  const [searchTerm, setSearchTerm] = useState('');
  const [categoryFilter, setCategoryFilter] = useState('All');
  const [searchParams, _] = useSearchParams();

  useEffect(() => {
    if (searchParams.get('category')) {
      setCategoryFilter(searchParams.get('category'));
    }

    initializeCart();
  }, [initializeCart, searchParams]);

  const categories = [
    'All',
    'Birthday',
    'Wedding',
    'Special Occasion',
    'Seasonal',
  ];

  const filteredCakes = cakeData.filter((cake) => {
    const matchesSearch =
      cake.name.toLowerCase().includes(searchTerm.toLowerCase()) ||
      cake.description.toLowerCase().includes(searchTerm.toLowerCase());
    const matchesCategory =
      categoryFilter === 'All' || cake.category === categoryFilter;
    return matchesSearch && matchesCategory;
  });

  const handleAddToCart = (cake) => {
    if (!isAuthenticated) {
      toast.error('Authentication required!', {
        description: 'Please sign in to add to your cart.',
      });
      return;
    }

    addToCart({
      ...cake,
      quantity: 1,
    });

    toast.success('Added to cart!', {
      description: `${cake.name} has been added to your cart.`,
    });
  };

  return (
    <div className='container mx-auto px-4 py-8 md:py-12'>
      <div className='text-center mb-12'>
        <h1 className='text-4xl font-bold text-gray-800 mb-4'>Our Cake Menu</h1>
        <p className='text-gray-600 max-w-2xl mx-auto'>
          Browse our selection of handcrafted cakes made with premium
          ingredients and love
        </p>
      </div>

      {/* Search and Filter */}
      <div className='mb-8 flex flex-col md:flex-row gap-4 justify-between'>
        <div className='relative w-full md:w-1/3'>
          <Search className='absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400' />
          <Input
            type='text'
            placeholder='Search cakes...'
            value={searchTerm}
            onChange={(e) => setSearchTerm(e.target.value)}
            className='pl-10 rounded-full border-pink-200 focus-visible::border-pink-400 focus-visible:ring-pink-400'
          />
        </div>
        <div className='flex flex-wrap gap-2'>
          {categories.map((category) => (
            <Button
              key={category}
              variant={categoryFilter === category ? 'default' : 'outline'}
              onClick={() => setCategoryFilter(category)}
              className={`rounded-full ${
                categoryFilter === category
                  ? 'bg-pink-500 hover:bg-pink-600 text-white'
                  : 'border-pink-200 text-pink-600 hover:bg-pink-50'
              }`}
            >
              {category}
            </Button>
          ))}
        </div>
      </div>

      {/* Cake Grid */}
      {filteredCakes.length > 0 ? (
        <div className='grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-6 md:gap-8 lg:gap-12'>
          {filteredCakes.map((cake) => (
            <div
              key={cake.id}
              className='bg-white rounded-xl shadow-sm border overflow-hidden transition-transform hover:scale-105 hover:shadow-md'
            >
              <Link to={`${cake.id}`} className='block relative h-56'>
                <img
                  src={cake.image}
                  alt={cake.name}
                  className='object-cover w-full h-full'
                />
                <div className='absolute top-2 right-2 bg-pink-100 text-pink-600 px-2 py-1 rounded-full text-xs font-medium'>
                  {cake.category}
                </div>
              </Link>
              <div className='p-6'>
                <div className='flex justify-between items-start mb-2'>
                  <h3 className='text-xl font-semibold text-gray-800'>
                    {cake.name}
                  </h3>
                  <p className='text-pink-600 font-bold'>
                    ${cake.price.toFixed(2)}
                  </p>
                </div>
                <p className='text-gray-600 mb-4 line-clamp-2'>
                  {cake.description}
                </p>
                <Button
                  onClick={() => handleAddToCart(cake)}
                  className='w-full bg-yellow-100 hover:bg-yellow-200 text-yellow-800 rounded-full'
                >
                  <ShoppingCart className='mr-2 h-4 w-4' /> Add to Cart
                </Button>
              </div>
            </div>
          ))}
        </div>
      ) : (
        <div className='text-center py-12'>
          <h3 className='text-xl text-gray-600'>
            No cakes found matching your search.
          </h3>
          <Button
            onClick={() => {
              setSearchTerm('');
              setCategoryFilter('All');
            }}
            variant='outline'
            className='mt-4 border-pink-300 text-pink-600 hover:bg-pink-50 rounded-full'
          >
            Clear Filters
          </Button>
        </div>
      )}
    </div>
  );
}
