import { useState } from 'react';
import { useNavigate, Link } from 'react-router-dom';
import { toast } from 'sonner';
import { Cake, Lock, Mail, User } from 'lucide-react';

import { useAuthStore } from '@/lib/authStore';

import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { Label } from '@/components/ui/label';
import { Checkbox } from '@/components/ui/checkbox';

export default function Register() {
  const navigate = useNavigate();
  const { login } = useAuthStore();

  const [formData, setFormData] = useState({
    name: '',
    email: '',
    password: '',
    confirmPassword: '',
    agreeTerms: false,
  });

  const [errors, setErrors] = useState({});
  const [isSubmitting, setIsSubmitting] = useState(false);

  const handleChange = (e) => {
    const { name, value, type, checked } = e.target;
    setFormData((prev) => ({
      ...prev,
      [name]: type === 'checkbox' ? checked : value,
    }));

    // Clear error when field is being edited
    if (errors[name]) {
      setErrors((prev) => ({
        ...prev,
        [name]: '',
      }));
    }
  };

  const validateForm = () => {
    const newErrors = {};

    if (!formData.name.trim()) newErrors.name = 'Name is required';

    if (!formData.email.trim()) {
      newErrors.email = 'Email is required';
    } else if (!/\S+@\S+\.\S+/.test(formData.email)) {
      newErrors.email = 'Email is invalid';
    }

    if (!formData.password) {
      newErrors.password = 'Password is required';
    } else if (formData.password.length < 6) {
      newErrors.password = 'Password must be at least 6 characters';
    }

    if (formData.password !== formData.confirmPassword) {
      newErrors.confirmPassword = 'Passwords do not match';
    }

    if (!formData.agreeTerms) {
      newErrors.agreeTerms = 'You must agree to the terms and conditions';
    }

    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = (e) => {
    e.preventDefault();

    if (!validateForm()) return;

    setIsSubmitting(true);

    // Simulate registration process
    setTimeout(() => {
      // Check if user already exists
      const users = JSON.parse(localStorage.getItem('users') || '[]');
      const userExists = users.some((user) => user.email === formData.email);

      if (userExists) {
        setErrors({
          email: 'This email is already registered',
        });
        setIsSubmitting(false);
        return;
      }

      // Create new user
      const newUser = {
        id: Date.now().toString(),
        name: formData.name,
        email: formData.email,
        password: formData.password,
      };

      // Save to local storage
      localStorage.setItem('users', JSON.stringify([...users, newUser]));

      // Auto login
      login({
        id: newUser.id,
        name: newUser.name,
        email: newUser.email,
      });

      toast.success('Registration Successful!', {
        description: `Welcome to Golden Crust Bakery, ${newUser.name}!`,
      });

      setIsSubmitting(false);
      navigate('/');
    }, 1500);
  };

  return (
    <div className='container mx-auto px-4 py-8 md:py-12'>
      <div className='max-w-md mx-auto'>
        <div className='text-center mb-8'>
          <div className='mx-auto w-16 h-16 bg-pink-100 rounded-full flex items-center justify-center mb-4'>
            <Cake className='h-8 w-8 text-pink-500' />
          </div>
          <h1 className='text-3xl font-bold text-gray-800 mb-2'>
            Create an Account
          </h1>
          <p className='text-gray-600'>
            Join Golden Crust Bakery to order delicious cakes
          </p>
        </div>

        <div className='bg-white rounded-xl border shadow-sm overflow-hidden'>
          <div className='p-6'>
            <form onSubmit={handleSubmit} className='space-y-6'>
              <div className='space-y-2'>
                <Label htmlFor='name'>Full Name</Label>
                <div className='relative'>
                  <User className='absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 h-5 w-5' />
                  <Input
                    id='name'
                    name='name'
                    value={formData.name}
                    onChange={handleChange}
                    className={`pl-10 rounded-lg ${
                      errors.name ? 'border-red-500' : 'border-gray-200'
                    }`}
                    placeholder='Peter Parker'
                  />
                </div>
                {errors.name && (
                  <p className='text-red-500 text-sm'>{errors.name}</p>
                )}
              </div>

              <div className='space-y-2'>
                <Label htmlFor='email'>Email Address</Label>
                <div className='relative'>
                  <Mail className='absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 h-5 w-5' />
                  <Input
                    id='email'
                    name='email'
                    type='email'
                    value={formData.email}
                    onChange={handleChange}
                    className={`pl-10 rounded-lg ${
                      errors.email ? 'border-red-500' : 'border-gray-200'
                    }`}
                    placeholder='yourname@email.com'
                  />
                </div>
                {errors.email && (
                  <p className='text-red-500 text-sm'>{errors.email}</p>
                )}
              </div>

              <div className='space-y-2'>
                <Label htmlFor='password'>Password</Label>
                <div className='relative'>
                  <Lock className='absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 h-5 w-5' />
                  <Input
                    id='password'
                    name='password'
                    type='password'
                    value={formData.password}
                    onChange={handleChange}
                    className={`pl-10 rounded-lg ${
                      errors.password ? 'border-red-500' : 'border-gray-200'
                    }`}
                    placeholder='********'
                  />
                </div>
                {errors.password && (
                  <p className='text-red-500 text-sm'>{errors.password}</p>
                )}
              </div>

              <div className='space-y-2'>
                <Label htmlFor='confirmPassword'>Confirm Password</Label>
                <div className='relative'>
                  <Lock className='absolute left-3 top-1/2 transform -translate-y-1/2 text-gray-400 h-5 w-5' />
                  <Input
                    id='confirmPassword'
                    name='confirmPassword'
                    type='password'
                    value={formData.confirmPassword}
                    onChange={handleChange}
                    className={`pl-10 rounded-lg ${
                      errors.confirmPassword
                        ? 'border-red-500'
                        : 'border-gray-200'
                    }`}
                    placeholder='********'
                  />
                </div>
                {errors.confirmPassword && (
                  <p className='text-red-500 text-sm'>
                    {errors.confirmPassword}
                  </p>
                )}
              </div>

              <div className='flex items-start space-x-2'>
                <Checkbox
                  id='agreeTerms'
                  name='agreeTerms'
                  checked={formData.agreeTerms}
                  onCheckedChange={(checked) => {
                    setFormData((prev) => ({
                      ...prev,
                      agreeTerms: checked,
                    }));
                    if (errors.agreeTerms) {
                      setErrors((prev) => ({
                        ...prev,
                        agreeTerms: '',
                      }));
                    }
                  }}
                  className={errors.agreeTerms ? 'border-red-500' : ''}
                />
                <div className='grid gap-1.5 leading-none'>
                  <label
                    htmlFor='agreeTerms'
                    className='text-sm font-medium leading-none peer-disabled:cursor-not-allowed peer-disabled:opacity-70'
                  >
                    I agree to the{' '}
                    <Link to='#' className='text-pink-600 hover:underline'>
                      Terms of Service
                    </Link>{' '}
                    and{' '}
                    <Link to='#' className='text-pink-600 hover:underline'>
                      Privacy Policy
                    </Link>
                  </label>
                  {errors.agreeTerms && (
                    <p className='text-red-500 text-sm'>{errors.agreeTerms}</p>
                  )}
                </div>
              </div>

              <Button
                type='submit'
                disabled={isSubmitting}
                className='w-full bg-pink-500 hover:bg-pink-600 text-white rounded-full py-6'
              >
                {isSubmitting ? 'Creating Account...' : 'Create Account'}
              </Button>
            </form>

            <div className='mt-6 text-center'>
              <p className='text-gray-600'>
                Already have an account?{' '}
                <Link
                  to='/login'
                  className='text-pink-600 hover:underline font-medium'
                >
                  Sign in
                </Link>
              </p>
            </div>
          </div>
        </div>

        <div className='mt-8 text-center'>
          <Button
            variant='ghost'
            asChild
            className='text-gray-600 hover:text-gray-800'
          >
            <Link to='/'>Return to Home</Link>
          </Button>
        </div>
      </div>
    </div>
  );
}
