'use client';

import type React from 'react';
import { createContext, useContext, useState, useEffect } from 'react';

type AccessibilityContextType = {
  highContrast: boolean;
  toggleHighContrast: () => void;
  textSize: number;
  increaseTextSize: () => void;
  decreaseTextSize: () => void;
  resetTextSize: () => void;
};

const AccessibilityContext = createContext<
  AccessibilityContextType | undefined
>(undefined);

export const AccessibilityProvider = ({
  children,
}: {
  children: React.ReactNode;
}) => {
  const [highContrast, setHighContrast] = useState(false);
  const [textSize, setTextSize] = useState(1);

  useEffect(() => {
    const savedHighContrast = localStorage.getItem('highContrast') === 'true';
    const savedTextSize = Number.parseFloat(
      localStorage.getItem('textSize') || '1'
    );

    setHighContrast(savedHighContrast);
    setTextSize(savedTextSize);

    applyHighContrast(savedHighContrast);
    applyTextSize(savedTextSize);
  }, []);

  const applyHighContrast = (enabled: boolean) => {
    if (enabled) {
      document.documentElement.classList.add('high-contrast');
    } else {
      document.documentElement.classList.remove('high-contrast');
    }
  };

  const applyTextSize = (size: number) => {
    document.documentElement.style.setProperty(
      '--text-size-multiplier',
      size.toString()
    );
  };

  const toggleHighContrast = () => {
    const newValue = !highContrast;
    setHighContrast(newValue);
    localStorage.setItem('highContrast', newValue.toString());
    applyHighContrast(newValue);
  };

  const increaseTextSize = () => {
    const newSize = Math.min(textSize + 0.1, 1.5); // Max 1.5x
    setTextSize(newSize);
    localStorage.setItem('textSize', newSize.toString());
    applyTextSize(newSize);
  };

  const decreaseTextSize = () => {
    const newSize = Math.max(textSize - 0.1, 0.8); // Min 0.8x
    setTextSize(newSize);
    localStorage.setItem('textSize', newSize.toString());
    applyTextSize(newSize);
  };

  const resetTextSize = () => {
    setTextSize(1);
    localStorage.setItem('textSize', '1');
    applyTextSize(1);
  };

  return (
    <AccessibilityContext.Provider
      value={{
        highContrast,
        toggleHighContrast,
        textSize,
        increaseTextSize,
        decreaseTextSize,
        resetTextSize,
      }}
    >
      {children}
    </AccessibilityContext.Provider>
  );
};

export const useAccessibility = () => {
  const context = useContext(AccessibilityContext);
  if (context === undefined) {
    throw new Error(
      'useAccessibility must be used within an AccessibilityProvider'
    );
  }
  return context;
};
